@@ -1,8 +1,6 @@
 /*
   +----------------------------------------------------------------------+
-  | PHP Version 5                                                        |
-  +----------------------------------------------------------------------+
-  | Copyright (c) 1997-2010 The PHP Group                                |
+  | Copyright (c) The PHP Group                                          |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -16,14 +14,12 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id$ */
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "php.h"
-#include "ext/standard/php_smart_str.h"
+#include "Zend/zend_smart_str.h"
 #include "stomp.h"
 #include "php_stomp.h"
 #ifdef HAVE_NETINET_IN_H
@@ -36,27 +32,19 @@ extern zend_class_entry *stomp_ce_exception;
 
 /* {{{ DEBUG */
 #if PHP_DEBUG
-static void print_stomp_frame(stomp_frame_t *frame TSRMLS_DC) {
+static void print_stomp_frame(stomp_frame_t *frame) {
 	php_printf("------ START FRAME ------\n");
 	php_printf("%s\n", frame->command);
 	/* Headers */
 	if (frame->headers) {
-		char *key;
-		ulong pos;
-		zend_hash_internal_pointer_reset(frame->headers);
-
-		while (zend_hash_get_current_key(frame->headers, &key, &pos, 0) == HASH_KEY_IS_STRING) {
-			char *value = NULL;
-
-			php_printf("%s:", key);
-
-			if (zend_hash_get_current_data(frame->headers, (void **)&value) == SUCCESS) {
-				php_printf("%s", value);
+		zend_string *key;
+		zval *value;
+		ZEND_HASH_FOREACH_STR_KEY_VAL(frame->headers, key, value) {
+			if (!key) {
+				break;
 			}
-
-			php_printf("\n");
-			zend_hash_move_forward(frame->headers);
-		}
+			php_printf("%s:%s\n", ZSTR_VAL(key), Z_STRVAL_P(value));
+		} ZEND_HASH_FOREACH_END();
 	}
 	php_printf("\n%s\n", frame->body);
 	php_printf("------ END FRAME ------\n");
@@ -196,15 +184,14 @@ int stomp_writable(stomp_t *stomp)
 
 /* {{{ stomp_connect
  */
-int stomp_connect(stomp_t *stomp, const char *host, unsigned short port TSRMLS_DC)
+int stomp_connect(stomp_t *stomp, const char *host, unsigned short port)
 {
 	char error[1024];
-	socklen_t        size;
+	socklen_t size;
 	struct timeval tv;
 	int flag = 1;
 
-	if (stomp->host != NULL)
-	{
+	if (stomp->host != NULL) {
 		efree(stomp->host);
 	}
 	stomp->host = (char *) emalloc(strlen(host) + 1);
@@ -216,9 +203,9 @@ int stomp_connect(stomp_t *stomp, const char *host, unsigned short port TSRMLS_D
 	tv.tv_sec = stomp->options.connect_timeout_sec;
 	tv.tv_usec = stomp->options.connect_timeout_usec;
 
-	stomp->fd = php_network_connect_socket_to_host(stomp->host, stomp->port, SOCK_STREAM, 0, &tv, NULL, NULL, NULL, 0 TSRMLS_CC);
+	stomp->fd = php_network_connect_socket_to_host(stomp->host, stomp->port, SOCK_STREAM, 0, &tv, NULL, NULL, NULL, 0, 0);
 	if (stomp->fd == -1) {
-		snprintf(error, sizeof(error), "Unable to connect to %s:%ld", stomp->host, stomp->port);
+		snprintf(error, sizeof(error), "Unable to connect to %s:%d", stomp->host, stomp->port);
 		stomp_set_error(stomp, error, errno, "%s", strerror(errno));
 		return 0;
 	}
@@ -266,7 +253,7 @@ int stomp_connect(stomp_t *stomp, const char *host, unsigned short port TSRMLS_D
 #endif
 		return 1;
 	} else {
-		snprintf(error, sizeof(error), "Unable to connect to %s:%ld", stomp->host, stomp->port);
+		snprintf(error, sizeof(error), "Unable to connect to %s:%d", stomp->host, stomp->port);
 		stomp_set_error(stomp, error, errno, "%s", strerror(errno));
 		return 0;
 	}
@@ -308,7 +295,7 @@ void stomp_close(stomp_t *stomp)
 
 /* {{{ stomp_send
  */
-int stomp_send(stomp_t *stomp, stomp_frame_t *frame TSRMLS_DC)
+int stomp_send(stomp_t *stomp, stomp_frame_t *frame)
 {
 	smart_str buf = {0};
 
@@ -318,25 +305,14 @@ int stomp_send(stomp_t *stomp, stomp_frame_t *frame TSRMLS_DC)
 
 	/* Headers */
 	if (frame->headers) {
-
-		char *key;
-		ulong pos;
-		zend_hash_internal_pointer_reset(frame->headers);
-
-		while (zend_hash_get_current_key(frame->headers, &key, &pos, 0) == HASH_KEY_IS_STRING) {
-			char *value = NULL;
-
-			smart_str_appends(&buf, key);
+		zend_string *key;
+		zval *value;
+		ZEND_HASH_FOREACH_STR_KEY_VAL(frame->headers, key, value) {
+			smart_str_appends(&buf, ZSTR_VAL(key));
 			smart_str_appendc(&buf, ':');
-
-			if (zend_hash_get_current_data(frame->headers, (void **)&value) == SUCCESS) {
-				smart_str_appends(&buf, value);
-			}
-
+			smart_str_appends(&buf, Z_STRVAL_P(value));
 			smart_str_appendc(&buf, '\n');
-
-			zend_hash_move_forward(frame->headers);
-		}
+		} ZEND_HASH_FOREACH_END();
 	}
 
 	if (frame->body_length > 0) {
@@ -348,7 +324,7 @@ int stomp_send(stomp_t *stomp, stomp_frame_t *frame TSRMLS_DC)
 	smart_str_appendc(&buf, '\n');
 
 	if (frame->body > 0) {
-		smart_str_appendl(&buf, frame->body, frame->body_length > 0 ? frame->body_length : strlen(frame->body));
+		smart_str_appendl(&buf, frame->body, frame->body_length);
 	}
 
 	smart_str_appendl(&buf, "\0", sizeof("\0")-1);
@@ -362,14 +338,14 @@ int stomp_send(stomp_t *stomp, stomp_frame_t *frame TSRMLS_DC)
 #ifdef HAVE_STOMP_SSL
 	if (stomp->options.use_ssl) {
 		int ret;
-		if (-1 == (ret = SSL_write(stomp->ssl_handle, buf.c, buf.len))) {
+		if (-1 == (ret = SSL_write(stomp->ssl_handle, ZSTR_VAL(buf.s), ZSTR_LEN(buf.s)))) {
 			smart_str_free(&buf);
 			stomp_set_error(stomp, "Unable to send data", errno, "SSL error %d", SSL_get_error(stomp->ssl_handle, ret));
 			return 0;
 		}
 	} else {
 #endif
-		if (-1 == send(stomp->fd, buf.c, buf.len, 0)) {
+		if (-1 == send(stomp->fd, ZSTR_VAL(buf.s), ZSTR_LEN(buf.s), 0)) {
 			smart_str_free(&buf);
 			stomp_set_error(stomp, "Unable to send data", errno, "%s", strerror(errno));
 			return 0;
@@ -577,7 +553,7 @@ void stomp_free_frame(stomp_frame_t *frame)
 		}
 		if (frame->headers) {
 			zend_hash_destroy(frame->headers);
-			efree(frame->headers);
+			FREE_HASHTABLE(frame->headers);
 		}
 		efree(frame);
 	}
@@ -589,7 +565,8 @@ void stomp_free_frame(stomp_frame_t *frame)
 stomp_frame_t *stomp_read_frame_ex(stomp_t *stomp, int use_stack)
 {
 	stomp_frame_t *f = NULL;
-	char *cmd = NULL, *length_str = NULL;
+	char *cmd = NULL;
+	zval *length_str = NULL;
 	int length = 0;
 
 	if (use_stack && stomp->frame_stack) {
@@ -629,7 +606,7 @@ stomp_frame_t *stomp_read_frame_ex(stomp_t *stomp, int use_stack)
 		} else {
 			char *p2 = NULL;
 			char *key;
-			char *value;
+			zval value;
 
 			p2 = strstr(p,":");
 
@@ -639,24 +616,24 @@ stomp_frame_t *stomp_read_frame_ex(stomp_t *stomp, int use_stack)
 			}
 
 			/* Null terminate the key */
-			*p2=0;
+			*p2 = 0;
 			key = p;
 
 			/* The rest is the value. */
-			value = p2+1;
+			ZVAL_STRING(&value, p2 + 1);
 
 			/* Insert key/value into hash table. */
-			zend_hash_add(f->headers, key, strlen(key) + 1, value, strlen(value) + 1, NULL);
+			zend_hash_str_add(f->headers, key, p2 - key, &value);
 			efree(p);
 		}
 	}
 
 	/* Check for the content length */
-	if (zend_hash_find(f->headers, "content-length", sizeof("content-length"), (void **)&length_str) == SUCCESS) {
+	if ((length_str = zend_hash_str_find(f->headers, ZEND_STRL("content-length"))) != NULL) {
 		int recv_size = 0;
 		char endbuffer[2];
 
-		f->body_length = atoi(length_str);
+		f->body_length = atoi(Z_STRVAL_P(length_str));
 		f->body = (char *) emalloc(f->body_length);
 
 		while (recv_size != f->body_length) {
@@ -685,18 +662,17 @@ stomp_frame_t *stomp_read_frame_ex(stomp_t *stomp, int use_stack)
  */
 int stomp_valid_receipt(stomp_t *stomp, stomp_frame_t *frame) {
 	int success = 1;
-	char *receipt = NULL;
+	zval *receipt;
 
-	if (zend_hash_find(frame->headers, "receipt", sizeof("receipt"), (void **)&receipt) == SUCCESS) {
+	if ((receipt = zend_hash_str_find(frame->headers, ZEND_STRL("receipt"))) != NULL) {
 		success = 0;
 		while (1) {
 			stomp_frame_t *res = stomp_read_frame_ex(stomp, 0);
 			if (res) {
 				if (0 == strncmp("RECEIPT", res->command, sizeof("RECEIPT") - 1)) {
-					char *receipt_id = NULL;
-					if (zend_hash_find(res->headers, "receipt-id", sizeof("receipt-id"), (void **)&receipt_id) == SUCCESS
-							&& strlen(receipt) == strlen(receipt_id)
-							&& !strcmp(receipt, receipt_id)) {
+					zval *receipt_id;
+					if ((receipt_id = zend_hash_str_find(res->headers, ZEND_STRL("receipt-id"))) != NULL
+							&& zend_string_equals(Z_STR_P(receipt), Z_STR_P(receipt_id))) {
 						success = 1;
 					} else {
 						stomp_set_error(stomp, "Invalid receipt", 0, "%s", receipt_id);
@@ -704,9 +680,9 @@ int stomp_valid_receipt(stomp_t *stomp, stomp_frame_t *frame) {
 					stomp_free_frame(res);
 					return success;
 				} else if (0 == strncmp("ERROR", res->command, sizeof("ERROR") - 1)) {
-					char *error_msg = NULL;
-					if (zend_hash_find(res->headers, "message", sizeof("message"), (void **)&error_msg) == SUCCESS) {
-						stomp_set_error(stomp, error_msg, 0, "%s", res->body);
+					zval *error_msg;
+					if ((error_msg = zend_hash_str_find(res->headers, ZEND_STRL("message"))) != NULL) {
+						stomp_set_error(stomp, Z_STRVAL_P(error_msg), 0, "%s", res->body);
 					}
 					stomp_free_frame(res);
 					return success;
@@ -747,3 +723,12 @@ int stomp_select_ex(stomp_t *stomp, const long int sec, const long int usec)
 	return 1;
 }
 /* }}} */
+
+/*
+ * Local variables:
+ * tab-width: 4
+ * c-basic-offset: 4
+ * End:
+ * vim600: noet sw=4 ts=4 fdm=marker
+ * vim<600: noet sw=4 ts=4
+ */
